Skip to contents

List cached datasets

Usage

cache_list()

Value

Invisibly returns a character vector of cached .rds file names. The visible output is a message listing the cache directory and file sizes, or a message that the cache is empty.