Extracts w_bar, R_local, n_bar, n_regions, and the tightness ratio from a projected sf object with a grouping column.
Usage
compute_stats(
sf_obj,
region_col,
centroid_fun = c("centroid", "point_on_surface")
)Extracts w_bar, R_local, n_bar, n_regions, and the tightness ratio from a projected sf object with a grouping column.
compute_stats(
sf_obj,
region_col,
centroid_fun = c("centroid", "point_on_surface")
)