Skip to contents

Print a grouped_exploded_map object

Usage

# S3 method for class 'grouped_exploded_map'
print(x, ...)

Arguments

x

A grouped_exploded_map object

...

Ignored

Value

Invisibly returns x, the original grouped_exploded_map object. The method is called for its side effect of printing a compact diagnostic overview of units, regions, grouping mode, and grouped-layout parameters.