Skip to contents

Summary of a grouped_exploded_map object

Usage

# S3 method for class 'grouped_exploded_map'
summary(object, ...)

Arguments

object

A grouped_exploded_map object

...

Ignored

Value

Invisibly returns object, the original grouped_exploded_map object. The method is called for its side effect of printing dataset size, grouping diagnostics, anchor parameters, and anchor radii.