R/tiger.R
cache_list.Rd
List cached datasets
cache_list()
Invisibly returns a character vector of cached .rds file names. The visible output is a message listing the cache directory and file sizes, or a message that the cache is empty.
.rds