Print an exploded_map object
Usage
# S3 method for class 'exploded_map'
print(x, ...)
Arguments
- x
An exploded_map object
- ...
Ignored
Value
Invisibly returns x, the original exploded_map object. The
method is called for its side effect of printing a compact diagnostic
overview of units, regions, derived parameters, and optional refinement
information.